import { EventSender } from '../types';
/**
 * A class extender for common chart methods
 * @param Sender the parent class to be extended
 */
export declare function CommonChart<S extends EventSender>(Sender: S): {
    new (...args: any[]): {
        /**
         * Sets a filter to the state of the chart entity in the Charts app component.
         * The filter gets applied to the embedded chart
         *
         * This expects an object that contains a valid [query operators](https://docs.mongodb.com/manual/reference/operator/query/#query-selectors).
         * Any fields referenced in this filter are expected to be whitelisted in the "Embed Chart" dialog for each Chart you wish to filter on.
         *
         * @returns a promise that resolves once the filter is saved and the component rerendered
         */
        setFilter(value: object): Promise<void>;
        /**
         * Returns the current filter applied to the embedded chart
         * The filter value is taken from the state of the chart entity in the Charts app component.
         *
         */
        getFilter(): Promise<object>;
        _send(msgName: string, ...payload: unknown[]): Promise<[unknown]>;
    };
} & S;
